@@ -22,6 +22,9 @@
 
 #include "diff2export.h"
 
+// Forward declaration needed
+class KTempDir;
+
 namespace Kompare
 {
 	enum Format {
@@ -49,12 +52,14 @@ namespace Kompare
 	};
 
 	enum Mode {
-		ComparingFiles,  // compareFiles
-		ComparingDirs,   // compareDirs
-		ShowingDiff,     // openDiff
-		BlendingDir,     // openDirAnfDiff
-		BlendingFile,    // openFileAndDiff
-		UnknownMode      // Used to initialize the Infoi struct
+		ComparingFiles,      // compareFiles
+		ComparingFileString, // Compare a source file with a destination string
+		ComparingStringFile, // Compare a source string with a destination file
+		ComparingDirs,       // compareDirs
+		ShowingDiff,         // openDiff
+		BlendingDir,         // openDirAnfDiff
+		BlendingFile,        // openFileAndDiff
+		UnknownMode          // Used to initialize the Infoi struct
 	};
 
 	enum DiffMode {
@@ -85,7 +90,11 @@ namespace Kompare
 			KUrl _source = KUrl(),
 			KUrl _destination = KUrl(),
 			QString _localSource = "",
-			QString _localDestination = ""
+			QString _localDestination = "",
+			KTempDir* _sourceKTempDir = 0,
+			KTempDir* _destinationKTempDir = 0,
+			uint _depth = 0,
+			bool _applied = true
 		)
 		{
 			mode = _mode;
@@ -96,6 +105,24 @@ namespace Kompare
 			destination = _destination;
 			localSource = _localSource;
 			localDestination = _localDestination;
+			sourceKTempDir = _sourceKTempDir;
+			destinationKTempDir = _destinationKTempDir;
+			depth = _depth;
+			applied = _applied;
+		}
+		void swapSourceWithDestination()
+		{
+			KUrl url = source;
+			source = destination;
+			destination = url;
+
+			QString string = localSource;
+			localSource = localDestination;
+			localDestination = string;
+
+			KTempDir* tmpDir = sourceKTempDir;
+			sourceKTempDir = destinationKTempDir;
+			destinationKTempDir = tmpDir;
 		}
 		enum Mode      mode;
 		enum DiffMode  diffMode;
@@ -105,6 +132,10 @@ namespace Kompare
 		KUrl           destination;
 		QString        localSource;
 		QString        localDestination;
+		KTempDir*      sourceKTempDir;
+		KTempDir*      destinationKTempDir;
+		uint           depth;
+		bool           applied;
 	};
 } // End of namespace Kompare
 
