@@ -18,23 +18,23 @@
 #ifndef PROPSVIEW_H
 #define PROPSVIEW_H
 
-#include <qwidget.h>
-#include <k3listview.h>
+#include <QWidget>
+#include <QTreeWidget>
 
 /**
   *@author Richard Moore
   */
 
-class PropsView : public K3ListView  {
-   Q_OBJECT
+class PropsView : public QTreeWidget  {
+  Q_OBJECT
 public: 
-	PropsView(QWidget *parent=0, const char *name=0);
-	~PropsView();
+  PropsView( QWidget *parent = 0 );
+  ~PropsView();
 
   void buildList( QObject *o );
 
 public slots:
-     void setTarget( QObject * );
+  void setTarget( QObject * );
 };
 
 #endif
