@@ -426,6 +426,23 @@ QString Catalog::mimetype()
 
     return m_storage->mimetype();
 }
+
+QString Catalog::sourceLangCode() const
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return QString();
+
+    return m_storage->sourceLangCode();
+}
+
+QString Catalog::targetLangCode() const
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return QString();
+
+    return m_storage->targetLangCode();
+}
+
 //END STORAGE TRANSLATION
 
 //BEGIN OPEN/SAVE
@@ -580,15 +597,16 @@ bool Catalog::saveToUrl(KUrl url)
         nameChanged=true;
 
 
-    bool remote=url.isLocalFile();
+    bool remote=!url.isLocalFile();
     QFile* file;
-    if (KDE_ISUNLIKELY( !remote ))
+    if (KDE_ISUNLIKELY( remote ))
         file=new KTemporaryFile();
     else
     {
         QString localFilePath=url.toLocalFile();
-        if (!QFileInfo(QFileInfo(localFilePath).canonicalPath()).exists())
-            if (!QDir::root().mkpath(QFileInfo(localFilePath).canonicalPath()))
+        QString localPath=QFileInfo(localFilePath).absolutePath();
+        if (!QFileInfo(localPath).exists())
+            if (!QDir::root().mkpath(localPath))
                 return false;
         file=new QFile(localFilePath);
     }
@@ -596,7 +614,8 @@ bool Catalog::saveToUrl(KUrl url)
     if (KDE_ISUNLIKELY( !file->open(QIODevice::WriteOnly) )) //i18n("Wasn't able to open file %1",filename.ascii());
         return false;
 
-    if (KDE_ISUNLIKELY( !m_storage->save(file) ))
+    bool belongsToProject=url.path().contains(Project::instance()->poDir());
+    if (KDE_ISUNLIKELY( !m_storage->save(file, belongsToProject) ))
         return false;
 
     QString localFile=file->fileName();
@@ -639,7 +658,10 @@ void Catalog::doAutoSave()
     if (KDE_ISUNLIKELY( !m_storage ))
         return;
     if (!d->_autoSave->open(QIODevice::WriteOnly))
+    {
+        emit signalFileAutoSaveFailed(d->_autoSave->fileName());
         return;
+    }
     qWarning()<<"doAutoSave"<<d->_autoSave->fileName();
     m_storage->save(d->_autoSave);
     d->_autoSave->close();
@@ -708,6 +730,11 @@ void Catalog::flushUpdateDBBuffer()
         //kWarning()<<"nothing to flush or new file opened";
         return;
     }
+    if (Project::instance()->targetLangCode()!=targetLangCode())
+    {
+        kWarning()<<"not updating because target languages don't match";
+        return;
+    }
     kWarning()<<"updating!!";
     int form=-1;
     if (isPlural(pos.entry))
