@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -28,13 +28,15 @@
 #include <klocale.h>
 #include <kglobal.h>
 
-static inline QString getMaillingList()
+static inline QString getMailingList()
 {
     QString lang(KGlobal::locale()->language());
     if(lang.startsWith("ca"))
         return "kde-i18n-ca@kde.org";
     if(lang.startsWith("de"))
         return "kde-i18n-de@kde.org";
+    if(lang.startsWith("hu"))
+        return "kde-l10n-hu@kde.org";
     if(lang.startsWith("it"))
         return "kde-i18n-it@kde.org";
     if(lang.startsWith("nb"))
