@@ -1,5 +1,5 @@
 /*
-    This file is part of the Okteta Kasten module, part of the KDE project.
+    This file is part of the Okteta Kasten module, made within the KDE community.
 
     Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
@@ -25,11 +25,13 @@
 // tool
 #include "infotool.h"
 #include "statistictablemodel.h"
+#include "infoviewsettings.h"
 // KDE
 #include <KPushButton>
 #include <KGuiItem>
 #include <KLocale>
 #include <KGlobal>
+#include <KApplication>
 #include <KGlobalSettings>
 // Qt
 #include <QtGui/QSortFilterProxyModel>
@@ -37,6 +39,7 @@
 #include <QtGui/QLayout>
 #include <QtGui/QHeaderView>
 #include <QtGui/QTreeView>
+#include <QtGui/QFontMetrics>
 
 
 namespace Kasten
@@ -64,13 +67,15 @@ InfoView::InfoView( InfoTool *tool, QWidget* parent )
 
     topLineLayout->addStretch();
 
-    const KGuiItem updateGuiItem(
-        i18nc("@action:button build the statistic of the byte frequency","&Build"),
-        "run-build",
-        i18nc("@info:tooltip","Builds the byte frequency statistic for the bytes in the selected range."),
-        i18nc("@info:whatsthis",
-              "If you press the <interface>Build</interface> button,"
-              " the byte frequency statistic is built for the bytes in the selected range.") );
+    const KGuiItem updateGuiItem =
+        KGuiItem(i18nc("@action:button build the statistic of the byte frequency",
+                       "&Build"),
+                 QLatin1String("run-build"),
+                 i18nc("@info:tooltip",
+                       "Builds the byte frequency statistic for the bytes in the selected range."),
+                 i18nc("@info:whatsthis",
+                       "If you press the <interface>Build</interface> button,"
+                       " the byte frequency statistic is built for the bytes in the selected range.") );
     mUpdateButton = new KPushButton( updateGuiItem, this );
     mUpdateButton->setEnabled( mTool->isApplyable() );
     connect( mTool, SIGNAL(isApplyableChanged(bool)), mUpdateButton, SLOT( setEnabled(bool )) );
@@ -81,7 +86,11 @@ InfoView::InfoView( InfoTool *tool, QWidget* parent )
 
     mStatisticTableView = new QTreeView( this );
     connect( KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()),
-            SLOT(setFixedFontByGlobalSettings()) );
+             SLOT(setFixedFontByGlobalSettings()) );
+    connect( KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()),
+             SLOT(resizeColumnsWidth()) );
+    connect( KGlobalSettings::self(), SIGNAL(kdisplayStyleChanged()),
+             SLOT(resizeColumnsWidth()) );
     setFixedFontByGlobalSettings(); //do this before setting model
     mStatisticTableView->setObjectName( QLatin1String( "StatisticTable" ) );
     mStatisticTableView->setRootIsDecorated( false );
@@ -91,7 +100,7 @@ InfoView::InfoView( InfoTool *tool, QWidget* parent )
     mStatisticTableView->setSortingEnabled( true );
     QHeaderView* header = mStatisticTableView->header();
     header->setFont( font() );
-    header->setResizeMode( QHeaderView::ResizeToContents );
+    header->setResizeMode( QHeaderView::Interactive );
     header->setStretchLastSection( false );
     // TODO: write subclass to filter count and percent by num, not string
     QSortFilterProxyModel *proxyModel = new QSortFilterProxyModel( this );
@@ -104,6 +113,23 @@ InfoView::InfoView( InfoTool *tool, QWidget* parent )
     baseLayout->addWidget( mStatisticTableView, 10 );
 
     setByteArraySize( mTool->size() );
+    
+    //if nothing has changed reuse the old values. This means the info view is fully constructed much quicker.
+    const QList<int> columnsWidth = InfoViewSettings::columnsWidth();
+    const QString styleName = KApplication::style()->objectName();
+    const QString fixedFontData = KGlobalSettings::fixedFont().toString();
+    if ( columnsWidth.size() < StatisticTableModel::NoOfIds || styleName != InfoViewSettings::style()
+            || fixedFontData != InfoViewSettings::fixedFont() )
+    {
+        resizeColumnsWidth();
+    }
+    else 
+    {
+        for (int i = 0; i < StatisticTableModel::NoOfIds; ++i) 
+        {
+            header->resizeSection( i, columnsWidth.at( i ) );
+        }
+    }
 }
 
 void InfoView::updateHeader()
@@ -113,10 +139,19 @@ void InfoView::updateHeader()
         StatisticTableModel::ValueId, StatisticTableModel::ValueId );
 }
 
+void InfoView::resizeColumnsWidth()
+{
+    //kDebug() << "recalculating header width";
+    for (int i = 0; i < StatisticTableModel::NoOfIds; ++i) 
+    {
+        mStatisticTableView->resizeColumnToContents( i );
+    }
+}
+
 void InfoView::setByteArraySize( int size )
 {
     const QString sizeText = ( size < 1 ) ? // -1 is default, 0 should not happen
-        QString( '-' ) :
+        QString::fromLatin1( "-" ) :
         i18np( "1 byte", "%1 bytes", size );
 
     mSizeLabel->setText( sizeText );
@@ -127,6 +162,18 @@ void InfoView::setFixedFontByGlobalSettings()
     mStatisticTableView->setFont( KGlobalSettings::fixedFont() );
 }
 
-InfoView::~InfoView() {}
+InfoView::~InfoView() 
+{
+    QList<int> columnsWidth;
+    const QHeaderView* header = mStatisticTableView->header();
+    for (int i = 0 ; i < StatisticTableModel::NoOfIds; ++i)
+    {
+        columnsWidth.append( header->sectionSize( i ) );
+    }
+    InfoViewSettings::setColumnsWidth( columnsWidth );
+    InfoViewSettings::setStyle( KApplication::style()->objectName() );
+    InfoViewSettings::setFixedFont( KGlobalSettings::fixedFont().toString() );
+    InfoViewSettings::self()->writeConfig();
+}
 
 }
