@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2010                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "association.h"
 
 // app includes
+#include "debug_utils.h"
 #include "classifier.h"
 #include "folder.h"
 #include "uml.h"
@@ -22,7 +23,6 @@
 #include "cmds.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 
 // qt includes
@@ -110,7 +110,7 @@ UMLAssociation::~UMLAssociation( )
 /**
  * Overloaded '==' operator
  */
-bool UMLAssociation::operator==(const UMLAssociation &rhs)
+bool UMLAssociation::operator==(const UMLAssociation &rhs) const
 {
     if (this == &rhs) {
         return true;
