@@ -1,55 +1,43 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2002-2011                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "cmd_handle_rename.h"
 
-#include "uml.h"
-
-// app includes
-#include "umlwidgetcontroller.h"
-#include "umlwidget.h"
-#include "umlwidgetlist.h"
-#include "umlnamespace.h"
-#include "umldoc.h"
-#include "umlview.h"
-#include "umlobject.h"
-#include "classifierwidget.h"
-#include "associationwidget.h"
-#include "messagewidget.h"
-
+#include "floatingtextwidget.h"
 
+// kde includes
 #include <klocale.h>
+#include <kdebug.h>
 
 namespace Uml
 {
 
-    CmdHandleRename::CmdHandleRename(FloatingTextWidget* _ftw, QString& txt):ftw(_ftw),newstring(txt)
+    CmdHandleRename::CmdHandleRename(FloatingTextWidget* ftw, QString& txt)
+      : m_ftw(ftw), m_newstring(txt)
     {
-        setText(i18n("Change text"));
-        oldstring = _ftw->getText();
+        m_oldstring = ftw->text();
+        setText(i18n("Change text : %1 to %2", m_oldstring, txt));
     }
 
     CmdHandleRename::~CmdHandleRename()
     {
-
     }
 
     void CmdHandleRename::redo()
     {
-        ftw->changeName(newstring);
+        m_ftw->changeName(m_newstring);
     }
 
     void CmdHandleRename::undo()
     {
-        ftw->changeName(oldstring);
+        m_ftw->changeName(m_oldstring);
     }
 
 }
