@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2007-2009                                               *
+ *   copyright (C) 2007-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -23,7 +23,7 @@ namespace Uml
     CmdChangeFontSelection::CmdChangeFontSelection(UMLDoc* doc, UMLView* view, QFont fon)
     {
         UMLWidget * widget = view->getFirstMultiSelectedWidget();
-        setText(i18n("Change Font")+ " : " + widget->name());
+        setText(i18n("Change font : %1", widget->name()));
         m_doc = doc;
         m_view = view;
         m_newFont = fon;
