@@ -5,24 +5,24 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "codedocument.h"
 
-// qt/kde includes
-#include <QtCore/QRegExp>
-#include <QtCore/QDateTime>
-#include <kdebug.h>
-
 // local includes
 #include "codegenerator.h"
+#include "debug_utils.h"
 #include "package.h"
 #include "umldoc.h"
 #include "uml.h"
 
+// qt includes
+#include <QtCore/QRegExp>
+#include <QtCore/QDateTime>
+
 /**
  * Constructor.
  */
