@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2002       Luis De la Parra Blum <luis@delaparra.org>   *
                               Brian Thomas <thomas@mail630.gsfc.nasa.gov>  *
- *   copyright (C) 2003-2010                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,12 +14,13 @@
 #include "codegenfactory.h"
 
 // app includes
+#include "attribute.h"
 #include "codegenerator.h"
-#include "umldoc.h"
-#include "uml.h"
+#include "debug_utils.h"
 #include "optionstate.h"
 #include "operation.h"
-#include "attribute.h"
+#include "uml.h"
+#include "umldoc.h"
 #include "umlrole.h"
 
 #include "adawriter.h"
@@ -90,16 +91,13 @@
 #include "javacodegenerationpolicy.h"
 #include "rubycodegenerationpolicy.h"
 
-// kde includes
-#include <kdebug.h>
-
 namespace CodeGenFactory
 {
 
 CodeGenerator* createObject(Uml::Programming_Language pl)
 {
     CodeGenerator* obj = 0;
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     switch (pl) {
         case Uml::pl_Ada:
             obj = new AdaWriter();
@@ -193,9 +191,9 @@ CodeGenerator* createObject(Uml::Programming_Language pl)
     return obj;
 }
 
-CodeDocument * newClassifierCodeDocument (UMLClassifier * c)
+CodeDocument * newClassifierCodeDocument(UMLClassifier * c)
 {
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     if (!optionState.generalState.newcodegen) {
         return NULL;
     }
@@ -360,8 +358,8 @@ CodeAccessorMethod * newCodeAccessorMethod(ClassifierCodeDocument *ccd,
     return retval;
 }
 
-CodeClassFieldDeclarationBlock * newDeclarationCodeBlock (ClassifierCodeDocument *cd,
-                                                          CodeClassField * cf)
+CodeClassFieldDeclarationBlock * newDeclarationCodeBlock(ClassifierCodeDocument *cd,
+                                                         CodeClassField * cf)
 {
     CodeClassFieldDeclarationBlock *retval = NULL;
     switch (UMLApp::app()->activeLanguage()) {
@@ -399,7 +397,7 @@ CodeClassFieldDeclarationBlock * newDeclarationCodeBlock (ClassifierCodeDocument
     return retval;
 }
 
-CodeComment * newCodeComment (CodeDocument *cd)
+CodeComment * newCodeComment(CodeDocument *cd)
 {
     switch (UMLApp::app()->activeLanguage()) {
         case Uml::pl_Cpp:
@@ -434,7 +432,7 @@ CodeComment * newCodeComment (CodeDocument *cd)
 
 CodeGenPolicyExt* newCodeGenPolicyExt(Uml::Programming_Language pl)
 {
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
 
     if ( pl == Uml::pl_Cpp ) {
         return new CPPCodeGenerationPolicy();
