@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,13 +14,11 @@
 
 // local includes
 #include "classifiercodedocument.h"
+#include "debug_utils.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlobject.h"
 
-// kde includes
-#include <kdebug.h>
-
 CodeOperation::CodeOperation ( ClassifierCodeDocument * doc , UMLOperation * parentOp, const QString & body, const QString & comment)
         : CodeMethodBlock ( doc, parentOp, body, comment)
 {
