@@ -339,7 +339,7 @@ void DClassifierCodeDocument::updateContent( )
     //
     QString pkgs = getPackage();
     pkgs.replace(QRegExp("::"), ".");
-    QString packageText = getPackage().isEmpty() ? "" : "package "+pkgs+';'+endLine;
+    QString packageText = getPackage().isEmpty() ? "" : QString("package "+pkgs+';'+endLine);
     CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments("packages", packageText, "", 0, false);
     if(packageText.isEmpty() && pblock->getContentType() == CodeBlock::AutoGenerated)
         pblock->setWriteOutText(false);
