@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2008                                               *
+ *   copyright (C) 2006-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -42,7 +42,7 @@ PascalWriter::~PascalWriter()
 {
 }
 
-Uml::Programming_Language PascalWriter::getLanguage()
+Uml::Programming_Language PascalWriter::language() const
 {
     return Uml::pl_Pascal;
 }
@@ -50,7 +50,7 @@ Uml::Programming_Language PascalWriter::getLanguage()
 
 bool PascalWriter::isOOClass(UMLClassifier *c)
 {
-    Uml::Object_Type ot = c->getBaseType();
+    Uml::Object_Type ot = c->baseType();
     if (ot == Uml::ot_Interface)
         return true;
     if (ot == Uml::ot_Enum)
@@ -59,7 +59,7 @@ bool PascalWriter::isOOClass(UMLClassifier *c)
         uDebug() << "unknown object type " << ot;
         return false;
     }
-    QString stype = c->getStereotype();
+    QString stype = c->stereotype();
     if (stype == "CORBAConstant" || stype == "CORBATypedef" ||
             stype == "CORBAStruct" || stype == "CORBAUnion")
         return false;
@@ -70,11 +70,11 @@ bool PascalWriter::isOOClass(UMLClassifier *c)
 
 QString PascalWriter::qualifiedName(UMLPackage *p, bool withType, bool byValue)
 {
-    UMLPackage *umlPkg = p->getUMLPackage();
-    QString className = cleanName(p->getName());
+    UMLPackage *umlPkg = p->umlPackage();
+    QString className = cleanName(p->name());
     QString retval;
 
-    if (umlPkg == UMLApp::app()->getDocument()->getRootFolder(Uml::mt_Logical))
+    if (umlPkg == UMLApp::app()->document()->rootFolder(Uml::mt_Logical))
         umlPkg = NULL;
 
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(p);
@@ -83,7 +83,7 @@ QString PascalWriter::qualifiedName(UMLPackage *p, bool withType, bool byValue)
         if (c == NULL || !isOOClass(c))
             retval.append(defaultPackageSuffix);
     } else {
-        retval = umlPkg->getFullyQualifiedName(".");
+        retval = umlPkg->fullyQualifiedName(".");
         if (isOOClass(c)) {
             retval.append(".");
             retval.append(className);
@@ -118,7 +118,7 @@ void PascalWriter::computeAssocTypeAndRole
     UMLClassifier* c = dynamic_cast<UMLClassifier*>(a->getObject(Uml::A));
     if (c == NULL)
         return;
-    typeName = cleanName(c->getName());
+    typeName = cleanName(c->name());
     if (! a->getMulti(Uml::A).isEmpty())
         typeName.append("_Array_Access");
 }
@@ -131,7 +131,7 @@ void PascalWriter::writeClass(UMLClassifier *c)
     }
 
     const bool isClass = !c->isInterface();
-    QString classname = cleanName(c->getName());
+    QString classname = cleanName(c->name());
     QString fileName = qualifiedName(c).toLower();
     fileName.replace('.', '-');
 
@@ -170,7 +170,7 @@ void PascalWriter::writeClass(UMLClassifier *c)
         pas << "uses" << m_endl;
         bool first = true;
         foreach (UMLPackage* con, imports ) {
-            if (con->getBaseType() != Uml::ot_Datatype) {
+            if (con->baseType() != Uml::ot_Datatype) {
                 if (first)
                     first = false;
                 else
@@ -183,15 +183,15 @@ void PascalWriter::writeClass(UMLClassifier *c)
 
     pas << "type" << m_endl;
     m_indentLevel++;
-    if (c->getBaseType() == Uml::ot_Enum) {
+    if (c->baseType() == Uml::ot_Enum) {
         UMLEnum *ue = static_cast<UMLEnum*>(c);
         UMLClassifierListItemList litList = ue->getFilteredList(Uml::ot_EnumLiteral);
         uint i = 0;
-        pas << getIndent() << classname << " = (" << m_endl;
+        pas << indent() << classname << " = (" << m_endl;
         m_indentLevel++;
         foreach (UMLClassifierListItem *lit , litList ) {
-            QString enumLiteral = cleanName(lit->getName());
-            pas << getIndent() << enumLiteral;
+            QString enumLiteral = cleanName(lit->name());
+            pas << indent() << enumLiteral;
             if (++i < ( uint )litList.count())
                 pas << "," << m_endl;
         }
@@ -203,18 +203,18 @@ void PascalWriter::writeClass(UMLClassifier *c)
     }
     UMLAttributeList atl = c->getAttributeList();
     if (! isOOClass(c)) {
-        QString stype = c->getStereotype();
+        QString stype = c->stereotype();
         if (stype == "CORBAConstant") {
-            pas << getIndent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
+            pas << indent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
         } else if(stype == "CORBAStruct") {
             if (isClass) {
 
-                pas << getIndent() << classname << " = record" << m_endl;
+                pas << indent() << classname << " = record" << m_endl;
                 m_indentLevel++;
                 foreach (UMLAttribute* at , atl ) {
-                    QString name = cleanName(at->getName());
+                    QString name = cleanName(at->name());
                     QString typeName = at->getTypeName();
-                    pas << getIndent() << name << " : " << typeName;
+                    pas << indent() << name << " : " << typeName;
                     QString initialVal = at->getInitialValue();
                     if (!initialVal.isEmpty())
                         pas << " := " << initialVal;
@@ -224,28 +224,28 @@ void PascalWriter::writeClass(UMLClassifier *c)
                 pas << "end;" << m_endl << m_endl;
             }
         } else if(stype == "CORBAUnion") {
-            pas << getIndent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
+            pas << indent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
         } else if(stype == "CORBATypedef") {
-            pas << getIndent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
+            pas << indent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
         } else {
-            pas << getIndent() << "// " << stype << ": Unknown stereotype" << m_endl << m_endl;
+            pas << indent() << "// " << stype << ": Unknown stereotype" << m_endl << m_endl;
         }
         m_indentLevel--;
-        pas << getIndent() << "end." << m_endl << m_endl;
+        pas << indent() << "end." << m_endl << m_endl;
         return;
     }
 
     // Write class Documentation if non-empty or if force option set.
-    if (forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->doc().isEmpty()) {
         pas << "//" << m_endl;
         pas << "// class " << classname << endl;
-        pas << formatDoc(c->getDoc(), "// ");
+        pas << formatDoc(c->doc(), "// ");
         pas << m_endl;
     }
 
     UMLClassifierList superclasses = c->getSuperClasses();
 
-    pas << getIndent() << classname << " = object";
+    pas << indent() << classname << " = object";
     if (!superclasses.isEmpty()) {
         // FIXME: Multiple inheritance is not yet supported
         UMLClassifier* parent = superclasses.first();
@@ -255,12 +255,12 @@ void PascalWriter::writeClass(UMLClassifier *c)
 
     UMLAttributeList atpub = c->getAttributeList(Uml::Visibility::Public);
     if (isClass && (forceSections() || atpub.count())) {
-        pas << getIndent() << "// Public attributes:" << m_endl;
+        pas << indent() << "// Public attributes:" << m_endl;
 
         foreach ( UMLAttribute* at  , atpub ) {
             // if (at->getStatic())
             //     continue;
-            pas << getIndent() << cleanName(at->getName()) << " : "
+            pas << indent() << cleanName(at->name()) << " : "
                 << at->getTypeName();
             if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
@@ -274,11 +274,11 @@ void PascalWriter::writeClass(UMLClassifier *c)
     UMLOperationList oppub;
 
     foreach (UMLOperation* op , opl ) {
-         if (op->getVisibility() == Uml::Visibility::Public)
+         if (op->visibility() == Uml::Visibility::Public)
             oppub.append(op);
     }
     if (forceSections() || oppub.count())
-        pas << getIndent() << "// Public methods:" << m_endl << m_endl;
+        pas << indent() << "// Public methods:" << m_endl << m_endl;
     foreach (UMLOperation* op , oppub )
         writeOperation(op, pas);
 
@@ -289,7 +289,7 @@ void PascalWriter::writeClass(UMLClassifier *c)
         foreach (UMLAttribute*  at , atprot ) {
             // if (at->getStatic())
             //     continue;
-            pas << getIndent() << cleanName(at->getName()) << " : "
+            pas << indent() << cleanName(at->name()) << " : "
                 << at->getTypeName();
             if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
@@ -305,7 +305,7 @@ void PascalWriter::writeClass(UMLClassifier *c)
         foreach (UMLAttribute* at , atpriv ) {
             // if (at->getStatic())
             //     continue;
-            pas << getIndent() << cleanName(at->getName()) << " : "
+            pas << indent() << cleanName(at->name()) << " : "
                 << at->getTypeName();
             if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
@@ -313,9 +313,9 @@ void PascalWriter::writeClass(UMLClassifier *c)
         }
         pas << m_endl;
     }
-    pas << getIndent() << "end;" << m_endl << m_endl;
+    pas << indent() << "end;" << m_endl << m_endl;
 
-    pas << getIndent() << "P" << classname << " = ^" << classname <<";" << m_endl << m_endl;
+    pas << indent() << "P" << classname << " = ^" << classname <<";" << m_endl << m_endl;
 
     m_indentLevel--;
     pas << "end;" << m_endl << m_endl;
@@ -325,31 +325,31 @@ void PascalWriter::writeClass(UMLClassifier *c)
 
 void PascalWriter::writeOperation(UMLOperation *op, QTextStream &pas, bool is_comment)
 {
-    if (op->getStatic()) {
-        pas << "// TODO: generate status method " << op->getName() << m_endl;
+    if (op->isStatic()) {
+        pas << "// TODO: generate status method " << op->name() << m_endl;
         return;
     }
     UMLAttributeList atl = op->getParmList();
     QString rettype = op->getTypeName();
     bool use_procedure = (rettype.isEmpty() || rettype == "void");
 
-    pas << getIndent();
+    pas << indent();
     if (is_comment)
         pas << "// ";
     if (use_procedure)
         pas << "procedure ";
     else
         pas << "function ";
-    pas << cleanName(op->getName()) << " ";
+    pas << cleanName(op->name()) << " ";
     if (atl.count()) {
         pas << "(" << m_endl;
         uint i = 0;
         m_indentLevel++;
         foreach (UMLAttribute *at , atl ) {
-            pas << getIndent();
+            pas << indent();
             if (is_comment)
                 pas << "// ";
-            pas << cleanName(at->getName()) << " : ";
+            pas << cleanName(at->name()) << " : ";
             Uml::Parameter_Direction pk = at->getParmKind();
             if (pk != Uml::pd_In)
                 pas << "var ";
@@ -373,11 +373,11 @@ void PascalWriter::writeOperation(UMLOperation *op, QTextStream &pas, bool is_co
     }
     else {
         pas << m_endl;
-        pas << getIndent() << "begin" << m_endl;
+        pas << indent() << "begin" << m_endl;
         m_indentLevel++;
-        pas << formatSourceCode(sourceCode, getIndent());
+        pas << formatSourceCode(sourceCode, indent());
         m_indentLevel--;
-        pas << getIndent() << "end;" << m_endl << m_endl;
+        pas << indent() << "end;" << m_endl << m_endl;
     }
 }
 
@@ -412,7 +412,7 @@ QStringList PascalWriter::defaultDatatypes()
 
 /**
  * Check whether the given string is a reserved word for the
- * language of this code generator
+ * language of this code generator.
  *
  * @param rPossiblyReservedKeyword  The string to check.
  */
@@ -429,9 +429,9 @@ bool PascalWriter::isReservedKeyword(const QString & rPossiblyReservedKeyword)
 }
 
 /**
- * get list of reserved keywords
+ * Get list of reserved keywords.
  */
-const QStringList PascalWriter::reservedKeywords() const
+QStringList PascalWriter::reservedKeywords() const
 {
     static QStringList keywords;
 
