@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2008                                               *
+ *   copyright (C) 2005-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,8 +14,6 @@
 // app includes
 #include "uml.h"
 #include "umldoc.h"
-#include "umllistview.h"
-#include "umllistviewitem.h"
 #include "umlobject.h"
 #include "package.h"
 #include "folder.h"
@@ -26,6 +24,7 @@
 #include "template.h"
 #include "association.h"
 #include "object_factory.h"
+#include "model_utils.h"
 
 // kde includes
 #include <kmessagebox.h>
@@ -165,9 +164,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                            const QString& stereotype)
 {
     QString name = inName;
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
-    const Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
+    UMLDoc *umldoc = UMLApp::app()->document();
+    UMLFolder *logicalView = umldoc->rootFolder(Uml::mt_Logical);
+    const Uml::Programming_Language pl = UMLApp::app()->activeLanguage();
     if (parentPkg == NULL) {
         // uDebug() << "Import_Utils::createUMLObject(" << name
         //     << "): parentPkg is NULL, assuming Logical View" << endl;
@@ -221,9 +220,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                     Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
                     o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
                     parentPkg = static_cast<UMLPackage*>(o);
-                    UMLListView *listView = UMLApp::app()->getListView();
-                    UMLListViewItem *lvitem = listView->findUMLObject(o);
-                    listView->setCurrentItem(lvitem);
+                    Model_Utils::treeViewSetCurrentItem(o);
                 }
                 // All scope qualified datatypes live in the global scope.
                 bPutAtGlobalScope = true;
@@ -240,7 +237,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             if (isConst)
                 name.prepend("const ");
             o = Object_Factory::createUMLObject(Uml::ot_Datatype, name,
-                                                umldoc->getDatatypeFolder(),
+                                                umldoc->datatypeFolder(),
                                                 false); //solicitNewName
             UMLClassifier *dt = static_cast<UMLClassifier*>(o);
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(origType);
@@ -263,8 +260,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             o = origType;
         }
     } else if (parentPkg && !bPutAtGlobalScope) {
-        UMLPackage *existingPkg = o->getUMLPackage();
-        if (existingPkg != umldoc->getDatatypeFolder()) {
+        UMLPackage *existingPkg = o->umlPackage();
+        if (existingPkg != umldoc->datatypeFolder()) {
             if (existingPkg)
                 existingPkg->removeObject(o);
             else
@@ -295,14 +292,14 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     QStringList::ConstIterator end(params.end());
     for (QStringList::ConstIterator it(params.begin()); it != end; ++it) {
         UMLObject *p = umldoc->findUMLObject(*it, Uml::ot_UMLObject, parentPkg);
-        if (p == NULL || p->getBaseType() == Uml::ot_Datatype)
+        if (p == NULL || p->baseType() == Uml::ot_Datatype)
             continue;
         const Uml::Association_Type at = Uml::at_Dependency;
         UMLAssociation *assoc = umldoc->findAssociation(at, gRelatedClassifier, p);
         if (assoc)
             continue;
         assoc = new UMLAssociation(at, gRelatedClassifier, p);
-        assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+        assoc->setUMLPackage(umldoc->rootFolder(Uml::mt_Logical));
         umldoc->addAssociation(assoc);
     }
     return o;
@@ -334,11 +331,11 @@ UMLObject* insertAttribute(UMLClassifier *owner,
                            const QString& comment /* ="" */,
                            bool isStatic /* =false */)
 {
-    Uml::Object_Type ot = owner->getBaseType();
-    Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
+    Uml::Object_Type ot = owner->baseType();
+    Uml::Programming_Language pl = UMLApp::app()->activeLanguage();
     if (! (ot == Uml::ot_Class || (ot == Uml::ot_Interface && pl == Uml::pl_Java))) {
         uDebug() << "insertAttribute: Don not know what to do with "
-                 << owner->getName() << " (object type " << ot << ")";
+                 << owner->name() << " (object type " << ot << ")";
         return NULL;
     }
     UMLObject *o = owner->findChildObject(name, Uml::ot_Attribute);
@@ -353,7 +350,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
         attr->setDoc(strippedComment);
     }
 
-    UMLApp::app()->getDocument()->setModified(true);
+    UMLApp::app()->document()->setModified(true);
     return attr;
 }
 
@@ -406,7 +403,7 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     op->setVisibility(scope);
     if (!type.isEmpty()     // return type may be missing (constructor/destructor)
         && type != "void") {
-        if (type == klass->getName()) {
+        if (type == klass->name()) {
             op->setType(klass);
         } else {
             UMLObject *typeObj = klass->findTemplate(type);
@@ -437,7 +434,7 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     }
 
     UMLAttributeList params = op->getParmList();
-    UMLOperation *exist = klass->checkOperationSignature(op->getName(), params);
+    UMLOperation *exist = klass->checkOperationSignature(op->name(), params);
     if (exist) {
         // copy contents to existing operation
         exist->setVisibility(scope);
@@ -448,11 +445,11 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
         UMLAttributeList exParams = exist->getParmList();
         for (UMLAttributeListIt it(params), exIt( exParams ) ; it.hasNext() ;) {
             UMLAttribute *param = it.next() , *exParam = exIt.next();
-            exParam->setName(param->getName());
-            exParam->setVisibility(param->getVisibility());
-            exParam->setStatic(param->getStatic());
-            exParam->setAbstract(param->getAbstract());
-            exParam->setDoc(param->getDoc());
+            exParam->setName(param->name());
+            exParam->setVisibility(param->visibility());
+            exParam->setStatic(param->isStatic());
+            exParam->setAbstract(param->isAbstract());
+            exParam->setDoc(param->doc());
             exParam->setInitialValue(param->getInitialValue());
             exParam->setParmKind(param->getParmKind());
         }
@@ -514,8 +511,8 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
         association = Uml::at_Realization;
     }
     UMLAssociation *assoc = new UMLAssociation(association, child, parent);
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+    UMLDoc *umldoc = UMLApp::app()->document();
+    assoc->setUMLPackage(umldoc->rootFolder(Uml::mt_Logical));
     umldoc->addAssociation(assoc);
 }
 
@@ -560,7 +557,7 @@ void addIncludePath(const QString& path)
  */
 bool isDatatype(const QString& name, UMLPackage *parentPkg)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     UMLObject * o = umldoc->findUMLObject(name, Uml::ot_Datatype, parentPkg);
     return (o!=NULL);
 }
