@@ -24,39 +24,28 @@
 #include <kdebug.h>
 #include <klocale.h>
 
-#include <qregexp.h>
-#include <qmap.h>
-#include <q3valuelist.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QMap>
+#include <QtCore/QList>
 
 #include <boost/bind.hpp>
 #include <boost/function.hpp>
-#include <boost/spirit/dynamic/if.hpp>
-#include <boost/spirit/phoenix/functions.hpp>
+#include <boost/spirit/include/classic_if.hpp>
+#include <boost/spirit/include/phoenix1_functions.hpp>
 
 #include "assignFunctor.hpp"
 
-namespace boost
-{
-namespace spirit {
-namespace impl {
-bool isalnum_(QChar const& c)
-{
-    return isalnum_(c.toAscii());
-}
-bool isalpha_(QChar const& c)
-{
-    return isalpha_(c.toAscii());
-}
-bool isblank_(QChar const& c)
-{
-    return isblank_(c.toAscii());
-}
-bool isdigit_(QChar const& c)
-{
-    return isdigit_(c.toAscii());
-}
-}
-}
+namespace boost {
+    namespace spirit {
+        namespace classic {
+            namespace impl {
+                bool isalnum_(QChar const& c) { return isalnum_(c.toAscii()); }
+                bool isalpha_(QChar const& c) { return isalpha_(c.toAscii()); }
+                bool isblank_(QChar const& c) { return isblank_(c.toAscii()); }
+                bool isdigit_(QChar const& c) { return isdigit_(c.toAscii()); }
+            }
+        }
+    }
 }
 
 template <class _Tp>
@@ -66,7 +55,7 @@ struct tilde : public std::unary_function<_Tp, _Tp> {
     }
 };
 
-using namespace boost::spirit;
+using namespace boost::spirit::classic;
 using phoenix::arg1;
 using phoenix::arg2;
 using phoenix::arg3;
@@ -82,9 +71,7 @@ SkipRule Lexer::m_SkipRule = nothing_p;
 class KDevTread: public QThread
 {
 public:
-    static void yield() {
-        msleep(0);
-    }
+    static void yield() { msleep(0); }
 };
 
 inline void qthread_yield()
@@ -216,7 +203,7 @@ struct numberLiteral :
 typedef std::pair<QString, int> Dependency;
 
 struct DependencyClosure
-            : boost::spirit::closure<DependencyClosure, QString, int> {
+            : boost::spirit::classic::closure<DependencyClosure, QString, int> {
     member1 m_word;
     member2 m_scope;
 };
@@ -267,7 +254,7 @@ using namespace std;
 
 struct LexerData {
     typedef QMap<QString, QString> Scope;
-    typedef Q3ValueList<Scope> StaticChain;
+    typedef QList<Scope> StaticChain;
 
     StaticChain staticChain;
 
@@ -426,6 +413,7 @@ void Lexer::tokenize()
 
 void Lexer::handleDirective(const QString& directive)
 {
+    Q_UNUSED(directive);
     assert(directive != "define");
     assert(directive != "else");
     assert(directive != "elif");
