@@ -124,7 +124,7 @@ void AssocPropDlg::setupFontPage()
     pageItem->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
     addPage( pageItem );
 
-    m_pChooser = new KFontChooser( (QWidget*)page, false, QStringList(), false);
+    m_pChooser = new KFontChooser( (QWidget*)page, KFontChooser::NoDisplayFlags, QStringList(), false);
     m_pChooser->setFont( m_pAssoc->getFont());
     m_pChooser->setSampleText(i18n("Association font"));
 }
