@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -158,7 +158,7 @@ bool UMLAttributeDialog::apply()
     QString name = m_pNameLE->text();
     if (name.isEmpty()) {
         KMessageBox::error(this, i18n("You have entered an invalid attribute name."),
-                           i18n("Attribute Name Invalid"), false);
+                           i18n("Attribute Name Invalid"), 0);
         m_pNameLE->setText( m_pAttribute->name() );
         return false;
     }
@@ -166,7 +166,7 @@ bool UMLAttributeDialog::apply()
     UMLObject *o = pConcept->findChildObject(name);
     if (o && o != m_pAttribute) {
         KMessageBox::error(this, i18n("The attribute name you have chosen is already being used in this operation."),
-                           i18n("Attribute Name Not Unique"), false);
+                           i18n("Attribute Name Not Unique"), 0);
         m_pNameLE->setText( m_pAttribute->name() );
         return false;
     }
@@ -181,7 +181,7 @@ bool UMLAttributeDialog::apply()
     }
     m_pAttribute->setVisibility(scope);
     // Set the scope as the default in the option state
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     optionState.classState.defaultAttributeScope = scope;
     Settings::setOptionState(optionState);
 
