@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2008                                                *
+ *  copyright (C) 2003-2010                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -34,7 +34,7 @@ UMLCheckConstraintDialog::UMLCheckConstraintDialog(QWidget* parent, UMLCheckCons
     showButtonSeparator( true );
 
     m_pCheckConstraint = pCheckConstraint;
-    m_doc = UMLApp::app()->getDocument();
+    m_doc = UMLApp::app()->document();
 
     setupDialog();
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
@@ -44,6 +44,9 @@ UMLCheckConstraintDialog::~UMLCheckConstraintDialog()
 {
 }
 
+/**
+ *   Sets up the dialog
+ */
 void UMLCheckConstraintDialog::setupDialog()
 {
     QFrame *frame = new QFrame( this );
@@ -77,9 +80,12 @@ void UMLCheckConstraintDialog::setupDialog()
     m_pCheckConditionTE->setText(m_pCheckConstraint->getCheckCondition());
 
     // set text of label
-    m_pNameLE->setText( m_pCheckConstraint->getName() );
+    m_pNameLE->setText( m_pCheckConstraint->name() );
 }
 
+/**
+ * Used when the OK button is clicked. Calls apply()
+ */
 void UMLCheckConstraintDialog::slotOk()
 {
     if ( apply() ) {
@@ -87,6 +93,9 @@ void UMLCheckConstraintDialog::slotOk()
     }
 }
 
+/**
+ * Apply Changes
+ */
 bool UMLCheckConstraintDialog::apply()
 {
     m_pCheckConstraint->setCheckCondition( m_pCheckConditionTE->toPlainText().trimmed() );
