@@ -180,7 +180,7 @@ bool UMLEntityAttributeDialog::apply()
     QString name = m_pNameLE->text();
     if (name.isEmpty()) {
         KMessageBox::error(this, i18n("You have entered an invalid entity attribute name."),
-                           i18n("Entity Attribute Name Invalid"), false);
+                           i18n("Entity Attribute Name Invalid"), 0);
         m_pNameLE->setText( m_pEntityAttribute->name() );
         return false;
     }
@@ -188,7 +188,7 @@ bool UMLEntityAttributeDialog::apply()
     UMLObject *o = pConcept->findChildObject(name);
     if (o && o != m_pEntityAttribute) {
         KMessageBox::error(this, i18n("The entity attribute name you have chosen is already being used in this operation."),
-                           i18n("Entity Attribute Name Not Unique"), false);
+                           i18n("Entity Attribute Name Not Unique"), 0);
         m_pNameLE->setText( m_pEntityAttribute->name() );
         return false;
     }
