@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -147,7 +147,7 @@ UMLWidgetColorPage::~UMLWidgetColorPage()
  */
 void UMLWidgetColorPage::slotLineButtonClicked()
 {
-    m_pLineColorB->setColor( Settings::getOptionState().uiState.lineColor );
+    m_pLineColorB->setColor( Settings::optionState().uiState.lineColor );
 }
 
 /**
@@ -156,7 +156,7 @@ void UMLWidgetColorPage::slotLineButtonClicked()
  */
 void UMLWidgetColorPage::slotFillButtonClicked()
 {
-    m_pFillColorB->setColor( Settings::getOptionState().uiState.fillColor );
+    m_pFillColorB->setColor( Settings::optionState().uiState.fillColor );
 }
 
 /**
@@ -165,7 +165,7 @@ void UMLWidgetColorPage::slotFillButtonClicked()
  */
 void UMLWidgetColorPage::slotBackgroundButtonClicked()
 {
-    m_BackgroundColorB->setColor( Settings::getOptionState().uiState.backgroundColor );
+    m_BackgroundColorB->setColor( Settings::optionState().uiState.backgroundColor );
 }
 
 /**
@@ -174,7 +174,7 @@ void UMLWidgetColorPage::slotBackgroundButtonClicked()
  */
 void UMLWidgetColorPage::slotGridDotButtonClicked()
 {
-    m_GridDotColorB->setColor( Settings::getOptionState().uiState.gridDotColor );
+    m_GridDotColorB->setColor( Settings::optionState().uiState.gridDotColor );
 }
 
 /**
