@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -78,12 +78,12 @@ void DocWindow::showDocumentation( UMLObject * object, bool overwrite )
         updateDocumentation( true );
     m_Showing = st_UMLObject;
     if( !object ) {
-        m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+        m_pDocTE->setText( m_pUMLDoc->documentation() );
         m_pUMLObject = 0;
         return;
     }
     m_pUMLObject = object;
-    m_pDocTE->setText( m_pUMLObject->getDoc() );
+    m_pDocTE->setText( m_pUMLObject->doc() );
 }
 
 /**
@@ -101,13 +101,11 @@ void DocWindow::showDocumentation( UMLObject * object, bool overwrite )
 void DocWindow::updateDocumentation( bool clear, bool startup )
 {
     bool mark_modified = false;
-    if( m_pUMLObject )
-    {
+    if ( m_pUMLObject ) {
         // the file is marked modified, if the documentation differs
         // we don't do this on startup/load of a xmi file, because every time
         // modified is set, we get another undo/redo backup point
-        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLObject->getDoc() )
-        {
+        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLObject->doc() ) {
             mark_modified = true;
         }
         m_pUMLObject->setDoc( m_pDocTE->toPlainText() );
@@ -116,8 +114,7 @@ void DocWindow::updateDocumentation( bool clear, bool startup )
         // the file is marked modified, if the documentation differs
         // we don't do this on startup/load of a xmi file, because every time
         // modified is set, we get another undo/redo backup point
-        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLView->getDoc() )
-        {
+        if ( (startup == false) && (m_pDocTE->toPlainText() != m_pUMLView->getDoc()) ) {
             mark_modified = true;
         }
 
@@ -126,18 +123,16 @@ void DocWindow::updateDocumentation( bool clear, bool startup )
         // the file is marked modified, if the documentation differs
         // we don't do this on startup/load of a xmi file, because every time
         // modified is set, we get another undo/redo backup point
-        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLWidget->documentation() )
-        {
+        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLWidget->documentation() ) {
             mark_modified = true;
         }
 
         m_pUMLWidget->setDocumentation( m_pDocTE->toPlainText() );
-    } else if( m_pAssocWidget ) {
+    } else if ( m_pAssocWidget ) {
         // the file is marked modified, if the documentation differs
         // we don't do this on startup/load of a xmi file, because every time
         // modified is set, we get another undo/redo backup point
-        if ( startup == false && m_pDocTE->toPlainText() != m_pAssocWidget->documentation() )
-        {
+        if ( startup == false && m_pDocTE->toPlainText() != m_pAssocWidget->documentation() ) {
             mark_modified = true;
         }
 
@@ -146,8 +141,7 @@ void DocWindow::updateDocumentation( bool clear, bool startup )
         // the file is marked modified, if the documentation differs
         // we don't do this on startup/load of a xmi file, because every time
         // modified is set, we get another undo/redo backup point
-        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLDoc->getDocumentation() )
-        {
+        if ( startup == false && m_pDocTE->toPlainText() != m_pUMLDoc->documentation() ) {
             mark_modified = true;
         }
 
@@ -155,12 +149,13 @@ void DocWindow::updateDocumentation( bool clear, bool startup )
     }
 
     // now do the setModified call
-    if (mark_modified == true)
+    if (mark_modified) {
         m_pUMLDoc->setModified( true );
+    }
 
     // we should show the documentation of the whole project
     if( clear ) {
-        m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+        m_pDocTE->setText( m_pUMLDoc->documentation() );
         m_pUMLObject = 0;
         m_pUMLView = 0;
         m_pUMLWidget = 0;
@@ -177,11 +172,12 @@ void DocWindow::showDocumentation( UMLView * view, bool overwrite )
 {
     if( view == m_pUMLView && !overwrite )
         return;
-    if( view != m_pUMLView )
+    if( view != m_pUMLView ) {
         updateDocumentation( true );
+    }
     m_Showing = st_UMLView;
     if( !view ) {
-        m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+        m_pDocTE->setText( m_pUMLDoc->documentation() );
         m_pUMLView = 0;
         return;
     }
@@ -202,7 +198,7 @@ void DocWindow::showDocumentation( UMLWidget * widget, bool overwrite )
         updateDocumentation( true );
     m_Showing = st_UMLWidget;
     if( !widget ) {
-        m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+        m_pDocTE->setText( m_pUMLDoc->documentation() );
         m_pUMLWidget = 0;
         return;
     }
@@ -223,7 +219,7 @@ void DocWindow::showDocumentation( AssociationWidget * widget, bool overwrite )
         updateDocumentation( true );
     m_Showing = st_Association;
     if( !widget ) {
-        m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+        m_pDocTE->setText( m_pUMLDoc->documentation() );
         m_pAssocWidget = 0;
         return;
     }
@@ -241,7 +237,7 @@ void DocWindow::newDocumentation( )
     m_pUMLWidget = 0;
     m_pAssocWidget = 0;
     m_Showing = st_Project;
-    m_pDocTE->setText( m_pUMLDoc->getDocumentation() );
+    m_pDocTE->setText( m_pUMLDoc->documentation() );
 }
 
 /**
