@@ -4,14 +4,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2010                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "enumliteral.h"
 
 #include <kinputdialog.h>
-#include <kdebug.h>
 #include <klocale.h>
 
 /**
@@ -47,7 +46,7 @@ UMLEnumLiteral::~UMLEnumLiteral()
 /**
  * Overloaded '==' operator
  */
-bool UMLEnumLiteral::operator==(const UMLEnumLiteral& rhs)
+bool UMLEnumLiteral::operator==(const UMLEnumLiteral& rhs) const
 {
     if ( this == &rhs )  {
         return true;
@@ -110,4 +109,3 @@ bool UMLEnumLiteral::showPropertiesDialog(QWidget* parent)
         return false;
     }
 }
-
