@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "foreignkeyconstraint.h"
 
 // app includes
+#include "debug_utils.h"
 #include "entity.h"
 #include "entityattribute.h"
 #include "umlobject.h"
@@ -20,9 +21,6 @@
 #include "umlforeignkeyconstraintdialog.h"
 #include "object_factory.h"
 
-// kde includes
-#include <kdebug.h>
-
 /**
  * Sets up a constraint.
  * @param parent    The parent of this UMLForeignKeyConstraint.
@@ -68,7 +66,7 @@ void UMLForeignKeyConstraint::init()
 /**
  * Overloaded '==' operator
  */
-bool UMLForeignKeyConstraint::operator==( const UMLForeignKeyConstraint &rhs)
+bool UMLForeignKeyConstraint::operator==( const UMLForeignKeyConstraint &rhs) const
 {
     if( this == &rhs )
         return true;
