@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -16,6 +16,8 @@
 #include "codeviewerstate.h"
 #include "codegenerationpolicy.h"
 
+#include <QtXml/QDomElement>
+
 namespace Settings {
 
 enum Page
@@ -36,7 +38,7 @@ struct GeneralState {
     bool angularlines;
     bool footerPrinting;
     bool autosave;
-    int time;        //old autosave time, kept for compatibility
+    int time;        ///< old autosave time, kept for compatibility
     int autosavetime;
     QString autosavesuffix;  ///< Text input field for suffix of autosave
     bool loadlast;
@@ -46,12 +48,12 @@ struct GeneralState {
 };
 
 struct UIState {
-    bool useFillColor;
+    bool   useFillColor;
     QColor fillColor;
     QColor lineColor;
     uint   lineWidth;
     QColor textColor;
-    QFont font;
+    QFont  font;
     QColor backgroundColor;
     QColor gridDotColor;
 };
@@ -70,9 +72,7 @@ struct ClassState {
     Uml::Visibility defaultOperationScope;
 };
 
-
-
-struct CodeGenerationState{
+struct CodeGenerationState {
     bool autoGenEmptyConstructors;
     CodeGenerationPolicy::CommentStyle commentStyle;
     Uml::Visibility::Value defaultAssocFieldScope;
@@ -88,7 +88,6 @@ struct CodeGenerationState{
     QDir outputDirectory;
     CodeGenerationPolicy::OverwritePolicy overwritePolicy;
 
-
     struct CPPCodeGenerationState {
         bool autoGenAccessors;
         bool inlineAccessors;
@@ -126,20 +125,20 @@ struct CodeGenerationState{
     DCodeGenerationState dCodeGenerationState;
     JavaCodeGenerationState javaCodeGenerationState;
     RubyCodeGenerationState rubyCodeGenerationState;
-
 };
 
 struct OptionState {
-    GeneralState generalState;
-    UIState uiState;
-    ClassState classState;
-    CodeViewerState codeViewerState;
+    GeneralState        generalState;
+    UIState             uiState;
+    ClassState          classState;
+    CodeViewerState     codeViewerState;
     CodeGenerationState codeGenerationState;
-
 };
 
-OptionState& getOptionState();
+OptionState& optionState();
 void setOptionState(const OptionState& optstate);
+void saveToXMI(QDomElement& element, const OptionState& optstate);
+bool loadFromXMI(QDomElement& element, OptionState& optstate);
 
 }  // namespace Settings
 
