@@ -79,6 +79,7 @@
 #include <QtCore/QRegExp>
 #include <QtCore/QTimer>
 #include <QtGui/QClipboard>
+#include <QtGui/QDialogButtonBox>
 #include <QtGui/QSlider>
 #include <QtGui/QToolButton>
 #include <QtGui/QKeyEvent>
@@ -88,6 +89,7 @@
 #include <QtGui/QStackedWidget>
 #include <QtGui/QPrinter>
 #include <QtGui/QPrintDialog>
+#include <QtGui/QPrintPreviewDialog>
 #include <QtGui/QUndoView>
 
 /** Static pointer, holding the last created instance. */
@@ -133,6 +135,9 @@ UMLApp::UMLApp(QWidget* parent) : KXmlGuiWindow(parent)
     m_doc = new UMLDoc();
     m_doc->init();
     m_hasBegunMacro = false;
+    m_printSettings = 0;
+    m_printer = new QPrinter;
+    m_printer->setFullPage(true);
 
     readOptionState();
     initActions();
@@ -187,6 +192,7 @@ UMLApp::~UMLApp()
     delete m_copyTimer;
     delete m_refactoringAssist;
     delete m_pUndoStack;
+    delete m_printer;
 }
 
 /**
@@ -221,6 +227,7 @@ void UMLApp::initActions()
     QAction* fileSaveAs = KStandardAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
     QAction* fileClose = KStandardAction::close(this, SLOT(slotFileClose()), actionCollection());
     filePrint = KStandardAction::print(this, SLOT(slotFilePrint()), actionCollection());
+    printPreview = KStandardAction::printPreview(this, SLOT(slotPrintPreview()), actionCollection());
     QAction* fileQuit = KStandardAction::quit(this, SLOT(slotFileQuit()), actionCollection());
 
     editUndo = m_pUndoStack->createUndoAction(actionCollection());
@@ -323,6 +330,7 @@ void UMLApp::initActions()
     fileSaveAs->setToolTip(i18n("Saves the document as..."));
     fileClose->setToolTip(i18n("Closes the document"));
     filePrint->setToolTip(i18n("Prints out the document"));
+    printPreview->setToolTip(i18n("Print Preview of the document"));
     fileQuit->setToolTip(i18n("Quits the application"));
     fileExportDocbook->setToolTip(i18n("Exports the model to the docbook format"));
     fileExportXhtml->setToolTip(i18n("Exports the model to the XHTML format"));
@@ -1162,6 +1170,58 @@ void UMLApp::slotFileClose()
     slotFileNew();
 }
 
+bool UMLApp::slotPrintSettings()
+{
+    if (m_printSettings)
+        delete m_printSettings;
+    m_printSettings = new DiagramPrintPage(0, m_doc);
+
+    QDialog *d = new QDialog;
+    QVBoxLayout *layout = new QVBoxLayout; 
+    layout->addWidget(m_printSettings);
+
+    QDialogButtonBox *b = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    connect(b, SIGNAL(accepted()), d, SLOT(accept()));
+    connect(b, SIGNAL(rejected()), d, SLOT(reject()));
+    layout->addWidget(b);
+    d->setLayout(layout);
+
+    bool result = d->exec() == QDialog::Accepted;
+
+    // keep settings
+    layout->removeWidget(m_printSettings);
+    m_printSettings->setParent(0);
+
+    delete d;
+    return result;
+}
+
+/**
+ * Print preview
+ */
+void UMLApp::slotPrintPreview()
+{
+    slotStatusMsg(i18n("Print Preview..."));
+
+    if(!slotPrintSettings())
+        return;
+
+    QPrintPreviewDialog *preview = new QPrintPreviewDialog(m_printer,this);
+    connect(preview, SIGNAL(paintRequested(QPrinter *)), this, SLOT(slotPrintPreviewPaintRequested(QPrinter *)));
+    preview->exec();
+    delete m_printSettings;
+    m_printSettings = 0;
+    resetStatusMsg();
+}
+
+/**
+ * Print preview painting slot
+ */
+void UMLApp::slotPrintPreviewPaintRequested(QPrinter *printer)
+{
+    m_doc->print(printer, m_printSettings);
+}
+
 /**
  * Print the current file.
  */
@@ -1169,17 +1229,18 @@ void UMLApp::slotFilePrint()
 {
     slotStatusMsg(i18n("Printing..."));
 
-    QPrinter printer;
-    printer.setFullPage(true);
+    if(!slotPrintSettings())
+        return;
 
-    DiagramPrintPage * selectPage = new DiagramPrintPage(0, m_doc);
     QPrintDialog *printDialog =
-                  KdePrint::createPrintDialog(&printer, QList<QWidget*>() << selectPage, this);
+                  KdePrint::createPrintDialog(m_printer, QList<QWidget*>() << m_printSettings, this);
     printDialog->setWindowTitle(i18n("Print %1", m_doc->url().prettyUrl()));
 
     if (printDialog->exec()) {
-        m_doc->print(&printer, selectPage);
+        m_doc->print(m_printer, m_printSettings);
     }
+    delete m_printSettings;
+    m_printSettings = 0;
     delete printDialog;
     resetStatusMsg();
 }
@@ -1506,6 +1567,7 @@ void UMLApp::setModified(bool modified)
 void UMLApp::enablePrint(bool enable)
 {
     filePrint->setEnabled(enable);
+    printPreview->setEnabled(enable);
 }
 
 /**
