@@ -33,6 +33,7 @@ class UMLViewImageExporterAll;
 class RefactoringAssistant;
 class KPlayerPopupSliderAction;
 class XhtmlGenerator;
+class DiagramPrintPage;
 
 // KDE forward declarations
 class KActionMenu;
@@ -192,6 +193,9 @@ public slots:
     void slotFileSave();
     bool slotFileSaveAs();
     void slotFileClose();
+    bool slotPrintSettings();
+    void slotPrintPreview();
+    void slotPrintPreviewPaintRequested(QPrinter *printer);
     void slotFilePrint();
     void slotFileQuit();
     void slotFileExportDocbook();
@@ -340,6 +344,7 @@ private:
 
     // KAction pointers to enable/disable actions
     KRecentFilesAction* fileOpenRecent;
+    QAction* printPreview;
     QAction* filePrint;
     QAction* editCut;
     QAction* editCopy;
@@ -404,6 +409,9 @@ private:
 
     bool m_hasBegunMacro;  ///< Macro creation flag.
 
+    DiagramPrintPage *m_printSettings; ///< printer diagram settings
+    QPrinter *m_printer;               ///< print instance
+
 signals:
     void sigCutSuccessful();
 
