@@ -1,18 +1,17 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLVIEWCANVAS_H
 #define UMLVIEWCANVAS_H
 
-#include <qcanvas.h>
+#include <q3canvas.h>
 
 /**
  *@author Paul Hensgen
@@ -20,29 +19,21 @@
  */
 class UMLView;
 
-class UMLViewCanvas : public QCanvas {
+class UMLViewCanvas : public Q3Canvas
+{
 public:
-    /**
-    *   Constructor
-    */
-    UMLViewCanvas( UMLView * pView );
-
-    /**
-    *   Deconstructor
-    */
+    UMLViewCanvas(UMLView * pView);
     virtual ~UMLViewCanvas();
 
+    void setColors(const QColor& backColor, const QColor& gridColor);
+    QColor gridDotColor() const; 
+
 protected:
 
-    /**
-    *   Overrides default method.
-    */
-    virtual void drawBackground( QPainter & painter, const QRect & clip );
+    virtual void drawBackground(QPainter & painter, const QRect & clip);
 
-    /**
-    *   The view the canvas is associated with.
-    */
-    UMLView * m_pView;
+    UMLView * m_pView;      ///< The view the canvas is associated with.
+    QColor    m_gridColor;  ///< Color for the grid dots.
 };
 
 #endif
