@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -82,7 +82,7 @@ public:
     /**
      * Overload '==' operator
      */
-    bool operator==(const UMLWidget& other);
+    bool operator==(const UMLWidget& other) const;
 
     /**
      * Calls the method with the same name in UMLWidgetController.
